==> location-0.0.2-sources.jar: com/locnavi/location/xunjimap/model/parse/Project.java <==
package com.locnavi.location.xunjimap.model.parse;


import com.parse.ParseClassName;
import com.parse.ParseGeoPoint;
import com.parse.ParseObject;
import com.parse.ParseRelation;
import com.locnavi.location.xunjimap.utils.ParseClass;

import org.json.JSONArray;

/**
 * author:chen
 * time:2017/4/20
 * desc:
 */

@ParseClassName(ParseClass.Project)
public class Project extends ParseObject {

    public String getBuildingId() {
        return getString("ipsmap_cloud_buildingid");
    }

    public String getToken() {
        return getString("ipsmap_cloud_token");
    }

    public String getBuildingIdBg() {
        return getString("bg_cloud_buildingid");
    }

    public String getTokenBg() {
        return getString("bg_cloud_token");
    }

    public String getName() {
        return getString("name");
    }

    public String getPicture() {
        return getString("picture");
    }

    public double getAngle() {
        return getDouble("angle");
    }

    public int getPowerThreshold() {
        return getInt("powerThreshold");
    }

    public int getInToOut() {
        return getInt("inToOut");
    }

    public int getOutToIn() {
        return getInt("outToIn");
    }

    public double getZoom() {
        return getDouble("zoom");
    }

    public int getFloorNumber() {
        return getInt("floorNumber");
    }

    public String getFloorName() {
        return getString("floorName");
    }


    public int getOrder() {
        return getInt("order");
    }

    public int getGpsFloorlayer() {
        return getInt("gpsFloorlayer");
    }

    public boolean isVisible() {
        return getBoolean("visible");
    }

    public double getNavigationZoom() {
        return getDouble("navigationZoom");
    }

    public ParseRelation<POIGenre> getGenres() {
        return getRelation("genre");
    }

    public boolean isDebug() {
        return getBoolean("isDebug");
    }

    public JSONArray getEscalatorFirst() {
        return getJSONArray("escalatorFirst");
    }

    public boolean isWiFi() {
        return getBoolean("wifi");
    }

    public ParseGeoPoint getCenterPoint() {
        return getParseGeoPoint("centerPoint");
    }

    public ParseObject getDistrict() {
        return getParseObject("district");
    }

    public String getTitle() {
        return getString("title");
    }

    public double getGpsoffsetLat() {
        return getDouble("gps_offset_lat");
    }

    public double getGpsoffsetLon() {
        return getDouble("gps_offset_lon");
    }
}

==> location-1.2.6-sources.jar: com/locnavi/location/xunjimap/model/parse/Project.java <==
package com.locnavi.location.xunjimap.model.parse;


import com.parse.ParseClassName;
import com.parse.ParseGeoPoint;
import com.parse.ParseObject;
import com.parse.ParseRelation;
import com.locnavi.location.xunjimap.utils.ParseClass;

import org.json.JSONArray;

/**
 * author:chen
 * time:2017/4/20
 * desc:
 */

@ParseClassName(ParseClass.Project)
public class Project extends ParseObject {

//    public String getBuildingId() {
//        return getString("ipsmap_cloud_buildingid");
//    }
//
//    public String getToken() {
//        return getString("ipsmap_cloud_token");
//    }

    public String getBuildingId() {
        return getString("building_id");
    }

    public String getToken() {
        return getString("cloud_token");
    }

    public String getBuildingIdBg() {
        return getString("bg_cloud_buildingid");
    }

    public String getTokenBg() {
        return getString("bg_cloud_token");
    }

    public String getName() {
        return getString("name");
    }

    public String getPicture() {
        return getString("picture");
    }

    public double getAngle() {
        return getDouble("angle");
    }

    public int getPowerThreshold() {
        return getInt("powerThreshold");
    }

    public int getInToOut() {
        return getInt("inToOut");
    }

    public int getOutToIn() {
        return getInt("outToIn");
    }

    public double getZoom() {
        return getDouble("zoom");
    }

    public int getFloorNumber() {
        return getInt("floorNumber");
    }

    public String getFloorName() {
        return getString("floorName");
    }


    public int getOrder() {
        return getInt("order");
    }

    public int getGpsFloorlayer() {
        return getInt("gpsFloorlayer");
    }

    public boolean isVisible() {
        return getBoolean("visible");
    }

    public double getNavigationZoom() {
        return getDouble("navigationZoom");
    }

    public ParseRelation<POIGenre> getGenres() {
        return getRelation("genre");
    }

    public boolean isDebug() {
        return getBoolean("isDebug");
    }

    public JSONArray getEscalatorFirst() {
        return getJSONArray("escalatorFirst");
    }

    public boolean isWiFi() {
        return getBoolean("wifi");
    }

    public ParseGeoPoint getCenterPoint() {
        return getParseGeoPoint("centerPoint");
    }

    public ParseObject getDistrict() {
        return getParseObject("district");
    }

    public String getTitle() {
        return getString("title");
    }

    public double getGpsoffsetLat() {
        return getDouble("gps_offset_lat");
    }

    public double getGpsoffsetLon() {
        return getDouble("gps_offset_lon");
    }
}
